<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>FacebookDepreceatedMessage</name>
    <message>
        <source>Facebook XMPP support is disabled since 01.05.2015. This means Kadu will be no longer able to connect to Facebook accounts. You can leave your Facebook accounts configured for chat history or you can remove them from Kadu using Your Account dialog</source>
        <translation>Podpora pro XMPP u služby Facebook je zakázána od verze 01.05.2015. Znamená to, že Kadu se už nebude moci připojit k účtům služby Facebook. Můžete své účty u služby Facebook ponechat nastaveny pro historii rozhovorů, nebo je můžete z Kadu odstranit pomocí dialogu pro váš účet.</translation>
    </message>
    <message>
        <source>Kadu - Facebook</source>
        <translation>Kadu - Facebook</translation>
    </message>
</context>
<context>
    <name>GTalkProtocolFactory</name>
    <message>
        <source>Gmail/Google Talk ID:</source>
        <translation>Gmail/Google Talk ID:</translation>
    </message>
</context>
<context>
    <name>JabberActions</name>
    <message>
        <source>Resend Subscription</source>
        <translation>Poslat odběr znovu</translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation>Odstranit odběr</translation>
    </message>
    <message>
        <source>Ask for Subscription</source>
        <translation>Požádat o odběr</translation>
    </message>
</context>
<context>
    <name>JabberAddAccountWidget</name>
    <message>
        <source>&lt;a href=&apos;#&apos;&gt;What is my username?&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;#&apos;&gt;Co je to to moje uživatelské jméno?&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Remember Password</source>
        <translation>Zapamatovat si heslo</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Totožnost účtu</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Vyberte nebo zadejte totožnost, která bude spojena s tímto účtem.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Add Account</source>
        <translation>Přidat účet</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>JabberChangePassword</name>
    <message>
        <source>Current connection is not safe for password change. Use encrypted connection or change password on provider&apos;s site.</source>
        <translation>Nynější spojení není bezpečné pro změnu hesla. Použijte šifrované spojení nebo heslo změňte na straně poskytovatele.</translation>
    </message>
    <message>
        <source>Password change is not allowed.</source>
        <translation>Změna hesla není povolena.</translation>
    </message>
</context>
<context>
    <name>JabberChangePasswordWindow</name>
    <message>
        <source>Change Password</source>
        <translation>Změnit heslo</translation>
    </message>
    <message>
        <source>New password</source>
        <translation>Nové heslo</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Enter new password for your XMPP/Jabber account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Zadejte nové heslo pro svůj účet XMPP/Jabber.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Retype new password</source>
        <translation>Napište nové heslo znovu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Changing password was successful.</source>
        <translation>Změna hesla byla úspěšná.</translation>
    </message>
    <message>
        <source>Invalid data entered in required fields.

Password entered in both fields (&quot;Password&quot; and &quot;Retype password&quot;) must be the same!</source>
        <translation>Do požadovaných polí byla zadána neplatná data.

Heslo zadané do obou polí (heslo a nové zadání hesla) se musí shodovat!</translation>
    </message>
    <message>
        <source>Log in before changing password.</source>
        <translation>Přihlašte se před změnou hesla.</translation>
    </message>
    <message>
        <source>Password change failed.

Error: %1</source>
        <translation>Změna hesla se nepodařila.

Chyba: %1</translation>
    </message>
</context>
<context>
    <name>JabberContactPersonalInfoWidget</name>
    <message>
        <source>Full Name</source>
        <translation>Celé jméno</translation>
    </message>
    <message>
        <source>Family Name</source>
        <translation>Rodné jméno</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Přezdívka</translation>
    </message>
    <message>
        <source>Birthdate</source>
        <translation>Datum narození</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Město</translation>
    </message>
    <message>
        <source>E-Mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Stránky</translation>
    </message>
</context>
<context>
    <name>JabberCreateAccountWidget</name>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Retype Password</source>
        <translation>Napište heslo znovu</translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation>Zapamatovat si heslo</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Totožnost účtu</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Vyberte nebo zadejte totožnost, která bude spojena s tímto účtem.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Register Account</source>
        <translation>Přihlásit účet</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Invalid data entered in required fields.

Password entered in both fields (&quot;New password&quot; and &quot;Retype password&quot;) must be the same!</source>
        <translation>Do požadovaných polí byla zadána neplatná data.

Heslo zadané do obou polí (nové heslo a nové zadání hesla) se musí shodovat!</translation>
    </message>
    <message>
        <source>E-mail:</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Some servers require your e-mail address during registration.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Některé servery vyžadují adresu elektronické pošty použitou během vytvoření  účtu (registrace).&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
</context>
<context>
    <name>JabberEditAccountWidget</name>
    <message>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Smazat účet</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation>Zapamatovat si heslo</translation>
    </message>
    <message>
        <source>Change your password</source>
        <translation>Změnit své heslo</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Totožnost účtu</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Vyberte nebo zadejte totožnost, která bude spojena s tímto účtem.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Personal Information</source>
        <translation>Osobní informace</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Připojení</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Přípojka</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Vždy</translation>
    </message>
    <message>
        <source>When available</source>
        <translation>Když je tato možnost dostupná</translation>
    </message>
    <message>
        <source>Allow plaintext authentication</source>
        <translation>Povolit ověření pravosti prostým textem</translation>
    </message>
    <message>
        <source>Over encrypted connection</source>
        <translation>Přes zašifrované spojení</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <source>Resource</source>
        <translation>Zdroj</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Přednost</translation>
    </message>
    <message>
        <source>Data transfer proxy</source>
        <translation>Proxy přenosu dat</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Remove account</source>
        <translation>Odstranit účet</translation>
    </message>
    <message>
        <source>Proxy configuration</source>
        <translation>Nastavení proxy</translation>
    </message>
    <message>
        <source>Publish system information</source>
        <translation>veřejnit informace o systému</translation>
    </message>
    <message>
        <source>XMPP Server</source>
        <translation>Server XMPP</translation>
    </message>
    <message>
        <source>Use custom server address/port</source>
        <translation>Použít vlastní adresu/přípojku serveru</translation>
    </message>
    <message>
        <source>Server address</source>
        <translation>Adresa serveru</translation>
    </message>
    <message>
        <source>Use encrypted connection</source>
        <translation>Použít šifrované připojení</translation>
    </message>
    <message>
        <source>Only in older version</source>
        <translation>Jen ve starší verzi</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Síť</translation>
    </message>
    <message>
        <source>Use computer name as a resource</source>
        <translation>Použít jméno počítače jako zdroj</translation>
    </message>
    <message>
        <source>Enable composing events</source>
        <translation>Povolit složené události</translation>
    </message>
    <message>
        <source>Your interlocutor will be notified when you are typing a message, before it is sent. And vice versa.</source>
        <translation>Účastník vašeho hovoru bude upozorněn, když budete psát zprávu, předtím než bude poslána. A naopak.</translation>
    </message>
    <message>
        <source>Enable chat activity events</source>
        <translation>Povolit události činnosti rozhovoru</translation>
    </message>
    <message>
        <source>Your interlocutor will be notified when you suspend or end conversation. And vice versa.</source>
        <translation>Účastník vašeho hovoru bude upozorněn, když rozhovor pozastavíte nebo ukončíte. A naopak.</translation>
    </message>
    <message>
        <source>Others can see your system name/version</source>
        <translation>Ostatní mohou vidět název/verzi vašeho systému</translation>
    </message>
    <message>
        <source>Confrim Account Removal</source>
        <translation>Potvrdit odstranění účtu</translation>
    </message>
    <message>
        <source>Are you sure do you want to remove account %1 (%2)?</source>
        <translation>Opravdu chcete odstranit účet %1 (%2)?</translation>
    </message>
    <message>
        <source>Require data transfer proxy:</source>
        <translation>Požadovat zástupce pro přenos dat:</translation>
    </message>
    <message>
        <source>Log in before changing password.</source>
        <translation>Přihlašte se před změnou hesla.</translation>
    </message>
</context>
<context>
    <name>JabberErrorService</name>
    <message>
        <source>Socket error: %1</source>
        <translation>Chyba zásuvky (socket): %1</translation>
    </message>
    <message>
        <source>Server did not respond for PING message</source>
        <translation>Server neodpověděl na zaklepání (odeslání průzkumné zprávy - pinknutí: PING)</translation>
    </message>
    <message>
        <source>Unknown error: %1/%2</source>
        <translation>Neznámá chyba: %1/%2</translation>
    </message>
    <message>
        <source>Bad request</source>
        <translation>Špatný požadavek</translation>
    </message>
    <message>
        <source>Conflict</source>
        <translation>Střet</translation>
    </message>
    <message>
        <source>Feature not implemented</source>
        <translation>Vlastnost neprovedena</translation>
    </message>
    <message>
        <source>Forbidden</source>
        <translation>Zakázáno</translation>
    </message>
    <message>
        <source>Gone</source>
        <translation>Hotovo</translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>Vnitřní chyba serveru</translation>
    </message>
    <message>
        <source>Item not found</source>
        <translation>Položka nenalezena</translation>
    </message>
    <message>
        <source>Jid malformed</source>
        <translation>JID poškozeno</translation>
    </message>
    <message>
        <source>Not acceptable</source>
        <translation>Nepřijatelné</translation>
    </message>
    <message>
        <source>Not allowed</source>
        <translation>Nedovoleno</translation>
    </message>
    <message>
        <source>Not authorized</source>
        <translation>Neoprávněno</translation>
    </message>
    <message>
        <source>Payment required</source>
        <translation>Požadována platba</translation>
    </message>
    <message>
        <source>Recipient unavailable</source>
        <translation>Příjemce nedostupný</translation>
    </message>
    <message>
        <source>Redirect</source>
        <translation>Přesměrování</translation>
    </message>
    <message>
        <source>Registration required</source>
        <translation>Registrace požadována</translation>
    </message>
    <message>
        <source>Remote server not found</source>
        <translation>Vzdálený server nenalezen</translation>
    </message>
    <message>
        <source>Remove server timeout</source>
        <translation>Časové omezení vzdáleného serveru</translation>
    </message>
    <message>
        <source>Resource constraint</source>
        <translation>Omezení zdroje</translation>
    </message>
    <message>
        <source>Service unavailable</source>
        <translation>Služba nedostupná</translation>
    </message>
    <message>
        <source>Subscription required</source>
        <translation>Zájem o odběr požadován</translation>
    </message>
    <message>
        <source>Undefined condition</source>
        <translation>Nestanovená podmínka</translation>
    </message>
    <message>
        <source>Unexpected request</source>
        <translation>Neočekávaný požadavek</translation>
    </message>
</context>
<context>
    <name>JabberOutgoingFileTransferHandler</name>
    <message>
        <source>Aborted</source>
        <translation>Zrušeno</translation>
    </message>
    <message>
        <source>File is corrupted</source>
        <translation>Soubor je poškozen</translation>
    </message>
    <message>
        <source>Protocol error</source>
        <translation>Chyba protokolu</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Neznámá chyba</translation>
    </message>
</context>
<context>
    <name>JabberPersonalInfoWidget</name>
    <message>
        <source>Full name</source>
        <translation>Celé jméno</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Přezdívka</translation>
    </message>
    <message>
        <source>Family name</source>
        <translation>Rodné jméno</translation>
    </message>
    <message>
        <source>Birth year</source>
        <translation>Rok narození</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Město</translation>
    </message>
    <message>
        <source>E-Mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Stránky</translation>
    </message>
</context>
<context>
    <name>JabberProtocol</name>
    <message>
        <source>Another client connected on the same resource.</source>
        <translation>Další klient připojený ke stejnému zdroji.</translation>
    </message>
</context>
<context>
    <name>JabberProtocolFactory</name>
    <message>
        <source>User JID:</source>
        <translation>Uživatelovo JID:</translation>
    </message>
</context>
<context>
    <name>JabberRegisterAccount</name>
    <message>
        <source>Internal error: invalid state</source>
        <translation>Vnitřní chyba: Neplatný stav</translation>
    </message>
    <message>
        <source>Connection established.</source>
        <translation>Spojení zřízeno.</translation>
    </message>
    <message>
        <source>Negotiating registration parameters.</source>
        <translation>Sjednávají se parametry registrace.</translation>
    </message>
    <message>
        <source>User with this username is already registered.</source>
        <translation>Uživatel s tímto jménem je již zaregistrován.</translation>
    </message>
    <message>
        <source>Registration parameters received.</source>
        <translation>Přijaty parametry registrace.</translation>
    </message>
    <message>
        <source>Registration at this server requires XMPP Data Forms support. Kadu currently does not support XMPP Data Forms.</source>
        <translation>Vytvoření účtu (registrace) u tohoto serveru vyžaduje podopru pro datové formuláře XMPP. Kadu nyní nepodporuje datové formuláře XMPP.</translation>
    </message>
    <message>
        <source>%1

Server message: %2</source>
        <translation>%1

Zpráva od serveru: %2</translation>
    </message>
    <message>
        <source>Unknown error: received stanza type %1</source>
        <translation>Neznáma chyba: Přijat typ sloky %1</translation>
    </message>
    <message>
        <source>SSL certificate rejected</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberStreamIncomingFileTransferHandler</name>
    <message>
        <source>Aborted</source>
        <translation>Zrušeno</translation>
    </message>
    <message>
        <source>File is corrupted</source>
        <translation>Soubor je poškozen</translation>
    </message>
    <message>
        <source>Protocol error</source>
        <translation>Chyba protokolu</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Neznámá chyba</translation>
    </message>
</context>
<context>
    <name>JabberWaitForAccountRegisterWindow</name>
    <message>
        <source>Registration was successful. Your new XMPP username is %1.
Store it in a safe place along with the password.
Now please add your friends to the buddy list.</source>
        <translation>Vytvoření účtu (registrace) bylo úspěšné. Vaše nové uživatelské jméno pro XMPP je %1.
Uložte je na bezpečném místě společně s heslem.
Nyní, prosím, přidejte své přátele do seznamu kamarádů.</translation>
    </message>
    <message>
        <source>Registering new XMPP account</source>
        <translation>Zaregistrování nového účtu XMPP</translation>
    </message>
    <message>
        <source>Registration failed.

Server message: %1</source>
        <translation>Registrace se nezdařila.

Zpráva od serveru: %1</translation>
    </message>
    <message>
        <source>Connecting with server.</source>
        <translation>Spojuje se se serverem.</translation>
    </message>
</context>
<context>
    <name>ShowXmlConsoleActionDescription</name>
    <message>
        <source>Show XML Console</source>
        <translation>Ukázat konzoli XML</translation>
    </message>
</context>
<context>
    <name>XmlConsole</name>
    <message>
        <source>XML Console - %1</source>
        <translation>Konzole XML - %1</translation>
    </message>
</context>
</TS>